==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/operation/MoveType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MoveType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MoveType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType"&gt;
 *       &lt;attribute name="mode" type="{http://schema.webpdf.de/1.0/operation}MoveModeType" default="afterPage" /&gt;
 *       &lt;attribute name="targetPosition" default="1"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="pages" type="{http://www.w3.org/2001/XMLSchema}string" default="1" /&gt;
 *       &lt;attribute name="order" type="{http://schema.webpdf.de/1.0/operation}OrderType" default="preserve" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MoveType")
public class MoveType
    extends BaseToolboxType
{

    @XmlAttribute(name = "mode")
    protected MoveModeType mode;
    @XmlAttribute(name = "targetPosition")
    protected Integer targetPosition;
    @XmlAttribute(name = "pages")
    protected String pages;
    @XmlAttribute(name = "order")
    protected OrderType order;

    /**
     * Gets the value of the mode property.
     * 
     * @return
     *     possible object is
     *     {@link MoveModeType }
     *     
     */
    public MoveModeType getMode() {
        if (mode == null) {
            return MoveModeType.AFTER_PAGE;
        } else {
            return mode;
        }
    }

    /**
     * Sets the value of the mode property.
     * 
     * @param value
     *     allowed object is
     *     {@link MoveModeType }
     *     
     */
    public void setMode(MoveModeType value) {
        this.mode = value;
    }

    public boolean isSetMode() {
        return (this.mode!= null);
    }

    /**
     * Gets the value of the targetPosition property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getTargetPosition() {
        if (targetPosition == null) {
            return  1;
        } else {
            return targetPosition;
        }
    }

    /**
     * Sets the value of the targetPosition property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setTargetPosition(int value) {
        this.targetPosition = value;
    }

    public boolean isSetTargetPosition() {
        return (this.targetPosition!= null);
    }

    public void unsetTargetPosition() {
        this.targetPosition = null;
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPages() {
        if (pages == null) {
            return "1";
        } else {
            return pages;
        }
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPages(String value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    /**
     * Gets the value of the order property.
     * 
     * @return
     *     possible object is
     *     {@link OrderType }
     *     
     */
    public OrderType getOrder() {
        if (order == null) {
            return OrderType.PRESERVE;
        } else {
            return order;
        }
    }

    /**
     * Sets the value of the order property.
     * 
     * @param value
     *     allowed object is
     *     {@link OrderType }
     *     
     */
    public void setOrder(OrderType value) {
        this.order = value;
    }

    public boolean isSetOrder() {
        return (this.order!= null);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/MoveType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The move operation element can be used to change the order of the document's pages.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for MoveType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="MoveType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType">
 *       <attribute name="mode" type="{http://schema.webpdf.de/1.0/operation}MoveModeType" default="afterPage" />
 *       <attribute name="targetPosition" default="1">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="pages" type="{http://www.w3.org/2001/XMLSchema}string" default="1" />
 *       <attribute name="order" type="{http://schema.webpdf.de/1.0/operation}OrderType" default="preserve" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MoveType")
public class MoveType
    extends BaseToolboxType
{

    @XmlAttribute(name = "mode")
    protected MoveModeType mode;
    @XmlAttribute(name = "targetPosition")
    protected Integer targetPosition;
    @XmlAttribute(name = "pages")
    protected String pages;
    @XmlAttribute(name = "order")
    protected OrderType order;

    /**
     * Gets the value of the mode property.
     * 
     * @return
     *     possible object is
     *     {@link MoveModeType }
     *     
     */
    public MoveModeType getMode() {
        if (mode == null) {
            return MoveModeType.AFTER_PAGE;
        } else {
            return mode;
        }
    }

    /**
     * Sets the value of the mode property.
     * 
     * @param value
     *     allowed object is
     *     {@link MoveModeType }
     *     
     */
    public void setMode(MoveModeType value) {
        this.mode = value;
    }

    public boolean isSetMode() {
        return (this.mode!= null);
    }

    /**
     * Gets the value of the targetPosition property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getTargetPosition() {
        if (targetPosition == null) {
            return  1;
        } else {
            return targetPosition;
        }
    }

    /**
     * Sets the value of the targetPosition property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setTargetPosition(int value) {
        this.targetPosition = value;
    }

    public boolean isSetTargetPosition() {
        return (this.targetPosition!= null);
    }

    public void unsetTargetPosition() {
        this.targetPosition = null;
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPages() {
        if (pages == null) {
            return "1";
        } else {
            return pages;
        }
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPages(String value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    /**
     * Gets the value of the order property.
     * 
     * @return
     *     possible object is
     *     {@link OrderType }
     *     
     */
    public OrderType getOrder() {
        if (order == null) {
            return OrderType.PRESERVE;
        } else {
            return order;
        }
    }

    /**
     * Sets the value of the order property.
     * 
     * @param value
     *     allowed object is
     *     {@link OrderType }
     *     
     */
    public void setOrder(OrderType value) {
        this.order = value;
    }

    public boolean isSetOrder() {
        return (this.order!= null);
    }

}
